"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    ca_certificate_id: str,
    page_size: int = None,
    marker: str = None,
    ascending_order: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List the device certificates signed by the specified CA certificate.

    Args:
        ca_certificate_id(str): The ID of the CA certificate. This operation will list all registered device certificate that were signed by this CA certificate.
        page_size(int, optional): The result page size. Defaults to None.
        marker(str, optional): The marker for the next set of results. Defaults to None.
        ascending_order(bool, optional): Specifies the order for results. If True, the results are returned in ascending order, based on the creation date. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.certificate.by_ca.list(ctx, ca_certificate_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.certificate.by_ca.list ca_certificate_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_certificates_by_ca",
        op_kwargs={
            "caCertificateId": ca_certificate_id,
            "pageSize": page_size,
            "marker": marker,
            "ascendingOrder": ascending_order,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    idempotency_token: str,
    ip_address_type: str = None,
    ip_addresses: List = None,
    enabled: bool = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a custom routing accelerator. A custom routing accelerator directs traffic to one of possibly thousands of Amazon EC2 instance destinations running in a single or multiple virtual private clouds (VPC) subnet endpoints. Be aware that, by default, all destination EC2 instances in a VPC subnet endpoint cannot receive traffic. To enable all destinations to receive traffic, or to specify individual port mappings that can receive traffic, see the  AllowCustomRoutingTraffic operation.  Global Accelerator is a global service that supports endpoints in multiple AWS Regions but you must specify the US West (Oregon) Region to create or update accelerators.

    Args:
        name(str): The name of a custom routing accelerator. The name can have a maximum of 64 characters, must contain only alphanumeric characters or hyphens (-), and must not begin or end with a hyphen.
        ip_address_type(str, optional): The value for the address type must be IPv4. Defaults to None.
        ip_addresses(List, optional): Optionally, if you've added your own IP address pool to Global Accelerator (BYOIP), you can choose IP addresses from your own pool to use for the accelerator's static IP addresses when you create an accelerator. You can specify one or two addresses, separated by a space. Do not include the /32 suffix. Only one IP address from each of your IP address ranges can be used for each accelerator. If you specify only one IP address from your IP address range, Global Accelerator assigns a second static IP address for the accelerator from the AWS IP address pool. Note that you can't update IP addresses for an existing accelerator. To change them, you must create a new accelerator with the new addresses. For more information, see Bring your own IP addresses (BYOIP) in the AWS Global Accelerator Developer Guide. Defaults to None.
        enabled(bool, optional): Indicates whether an accelerator is enabled. The value is true or false. The default value is true.  If the value is set to true, an accelerator cannot be deleted. If set to false, the accelerator can be deleted. Defaults to None.
        idempotency_token(str): A unique, case-sensitive identifier that you provide to ensure the idempotency—that is, the uniqueness—of the request.
        tags(List, optional): Create tags for an accelerator. For more information, see Tagging in AWS Global Accelerator in the AWS Global Accelerator Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.accelerator.init.create(
                ctx, name=value, idempotency_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.accelerator.init.create name=value, idempotency_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="create_custom_routing_accelerator",
        op_kwargs={
            "Name": name,
            "IpAddressType": ip_address_type,
            "IpAddresses": ip_addresses,
            "Enabled": enabled,
            "IdempotencyToken": idempotency_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, accelerator_arn: str) -> None:
    r"""
    **Autogenerated function**

    Delete a custom routing accelerator. Before you can delete an accelerator, you must disable it and remove all dependent resources (listeners and endpoint groups). To disable the accelerator, update the accelerator to set Enabled to false.  When you create a custom routing accelerator, by default, Global Accelerator provides you with a set of two static IP addresses.  The IP addresses are assigned to your accelerator for as long as it exists, even if you disable the accelerator and it no longer accepts or routes traffic. However, when you delete an accelerator, you lose the static IP addresses that are assigned to the accelerator, so you can no longer route traffic by using them. As a best practice, ensure that you have permissions in place to avoid inadvertently deleting accelerators. You can use IAM policies with Global Accelerator to limit the users who have permissions to delete an accelerator. For more information, see Authentication and Access Control in the AWS Global Accelerator Developer Guide.

    Args:
        accelerator_arn(str): The Amazon Resource Name (ARN) of the custom routing accelerator to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.accelerator.init.delete(
                ctx, accelerator_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.accelerator.init.delete accelerator_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="delete_custom_routing_accelerator",
        op_kwargs={"AcceleratorArn": accelerator_arn},
    )


async def describe(hub, ctx, accelerator_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describe a custom routing accelerator.

    Args:
        accelerator_arn(str): The Amazon Resource Name (ARN) of the accelerator to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.accelerator.init.describe(
                ctx, accelerator_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.accelerator.init.describe accelerator_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="describe_custom_routing_accelerator",
        op_kwargs={"AcceleratorArn": accelerator_arn},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    List the custom routing accelerators for an AWS account.

    Args:
        max_results(int, optional): The number of custom routing Global Accelerator objects that you want to return with this call. The default value is 10. Defaults to None.
        next_token(str, optional): The token for the next set of results. You receive this token from a previous call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.accelerator.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.accelerator.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="list_custom_routing_accelerators",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    accelerator_arn: str,
    name: str = None,
    ip_address_type: str = None,
    enabled: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update a custom routing accelerator.

    Args:
        accelerator_arn(str): The Amazon Resource Name (ARN) of the accelerator to update.
        name(str, optional): The name of the accelerator. The name can have a maximum of 32 characters, must contain only alphanumeric characters or hyphens (-), and must not begin or end with a hyphen. Defaults to None.
        ip_address_type(str, optional): The value for the address type must be IPv4. Defaults to None.
        enabled(bool, optional): Indicates whether an accelerator is enabled. The value is true or false. The default value is true.  If the value is set to true, the accelerator cannot be deleted. If set to false, the accelerator can be deleted. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.custom_routing.accelerator.init.update(
                ctx, accelerator_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.custom_routing.accelerator.init.update accelerator_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="update_custom_routing_accelerator",
        op_kwargs={
            "AcceleratorArn": accelerator_arn,
            "Name": name,
            "IpAddressType": ip_address_type,
            "Enabled": enabled,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def list_all(
    hub,
    ctx,
    filters: List = None,
    resource_ids: List = None,
    resource_types: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    For a specified resource ID, this API operation returns a list of compliance statuses for different resource types. Currently, you can only specify one resource ID per call. List results depend on the criteria specified in the filter.

    Args:
        filters(List, optional): One or more compliance filters. Use a filter to return a more specific list of results. Defaults to None.
        resource_ids(List, optional): The ID for the resources from which to get compliance information. Currently, you can only specify one resource ID. Defaults to None.
        resource_types(List, optional): The type of resource from which to get compliance information. Currently, the only supported resource type is ManagedInstance. Defaults to None.
        next_token(str, optional): A token to start the list. Use this token to get the next set of results. . Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.compliance.item.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.compliance.item.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="list_compliance_items",
        op_kwargs={
            "Filters": filters,
            "ResourceIds": resource_ids,
            "ResourceTypes": resource_types,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def put_multiple(
    hub,
    ctx,
    resource_id: str,
    resource_type: str,
    compliance_type: str,
    execution_summary: Dict,
    items: List,
    item_content_hash: str = None,
    upload_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Registers a compliance type and other compliance details on a designated resource. This operation lets you register custom compliance details with a resource. This call overwrites existing compliance information on the resource, so you must provide a full list of compliance items each time that you send the request. ComplianceType can be one of the following:   ExecutionId: The execution ID when the patch, association, or custom compliance item was applied.   ExecutionType: Specify patch, association, or Custom:string.   ExecutionTime. The time the patch, association, or custom compliance item was applied to the instance.   Id: The patch, association, or custom compliance ID.   Title: A title.   Status: The status of the compliance item. For example, approved for patches, or Failed for associations.   Severity: A patch severity. For example, critical.   DocumentName: An SSM document name. For example, AWS-RunPatchBaseline.   DocumentVersion: An SSM document version number. For example, 4.   Classification: A patch classification. For example, security updates.   PatchBaselineId: A patch baseline ID.   PatchSeverity: A patch severity. For example, Critical.   PatchState: A patch state. For example, InstancesWithFailedPatches.   PatchGroup: The name of a patch group.   InstalledTime: The time the association, patch, or custom compliance item was applied to the resource. Specify the time by using the following format: yyyy-MM-dd'T'HH:mm:ss'Z'

    Args:
        resource_id(str): Specify an ID for this resource. For a managed instance, this is the instance ID.
        resource_type(str): Specify the type of resource. ManagedInstance is currently the only supported resource type.
        compliance_type(str): Specify the compliance type. For example, specify Association (for a State Manager association), Patch, or Custom:string.
        execution_summary(Dict): A summary of the call execution that includes an execution ID, the type of execution (for example, Command), and the date/time of the execution using a datetime object that is saved in the following format: yyyy-MM-dd'T'HH:mm:ss'Z'.
        items(List): Information about the compliance as defined by the resource type. For example, for a patch compliance type, Items includes information about the PatchSeverity, Classification, and so on.
        item_content_hash(str, optional): MD5 or SHA-256 content hash. The content hash is used to determine if existing information should be overwritten or ignored. If the content hashes match, the request to put compliance information is ignored. Defaults to None.
        upload_type(str, optional): The mode for uploading compliance items. You can specify COMPLETE or PARTIAL. In COMPLETE mode, the system overwrites all existing compliance information for the resource. You must provide a full list of compliance items each time you send the request. In PARTIAL mode, the system overwrites compliance information for a specific association. The association must be configured with SyncCompliance set to MANUAL. By default, all requests use COMPLETE mode.  This attribute is only valid for association compliance. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.compliance.item.put_multiple(
                ctx,
                resource_id=value,
                resource_type=value,
                compliance_type=value,
                execution_summary=value,
                items=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.compliance.item.put_multiple resource_id=value, resource_type=value, compliance_type=value, execution_summary=value, items=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="put_compliance_items",
        op_kwargs={
            "ResourceId": resource_id,
            "ResourceType": resource_type,
            "ComplianceType": compliance_type,
            "ExecutionSummary": execution_summary,
            "Items": items,
            "ItemContentHash": item_content_hash,
            "UploadType": upload_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(hub, ctx, ids: List, namespace_version: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets definitions of the specified entities. Uses the latest version of the user's namespace by default. This API returns the following TDM entities.   Properties   States   Events   Actions   Capabilities   Mappings   Devices   Device Models   Services   This action doesn't return definitions for systems, flows, and deployments.

    Args:
        ids(List): An array of entity IDs. The IDs should be in the following format.  urn:tdm:REGION/ACCOUNT ID/default:device:DEVICENAME .
        namespace_version(int, optional): The version of the user's namespace. Defaults to the latest version of the user's namespace. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.entity.init.get_all(ctx, ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.entity.init.get_all ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="get_entities",
        op_kwargs={"ids": ids, "namespaceVersion": namespace_version},
    )


async def search(
    hub,
    ctx,
    entity_types: List,
    filters: List = None,
    next_token: str = None,
    max_results: int = None,
    namespace_version: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Searches for entities of the specified type. You can search for entities in your namespace and the public namespace that you're tracking.

    Args:
        entity_types(List): The entity types for which to search.
        filters(List, optional): Optional filter to apply to the search. Valid filters are NAME NAMESPACE, SEMANTIC_TYPE_PATH and REFERENCED_ENTITY_ID. REFERENCED_ENTITY_ID filters on entities that are used by the entity in the result set. For example, you can filter on the ID of a property that is used in a state. Multiple filters function as OR criteria in the query. Multiple values passed inside the filter function as AND criteria. Defaults to None.
        next_token(str, optional): The string that specifies the next page of results. Use this when you're paginating results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.
        namespace_version(int, optional): The version of the user's namespace. Defaults to the latest version of the user's namespace. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.entity.init.search(ctx, entity_types=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.entity.init.search entity_types=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="search_entities",
        op_kwargs={
            "entityTypes": entity_types,
            "filters": filters,
            "nextToken": next_token,
            "maxResults": max_results,
            "namespaceVersion": namespace_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    A list of email addresses and phone numbers that the Shield Response Team (SRT) can use to contact you if you have proactive engagement enabled, for escalations to the SRT and to initiate proactive customer support.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.emergency_contact_setting.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.emergency_contact_setting.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="shield",
        operation="describe_emergency_contact_settings",
        op_kwargs={},
    )


async def update_multiple(hub, ctx, emergency_contact_list: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the details of the list of email addresses and phone numbers that the Shield Response Team (SRT) can use to contact you if you have proactive engagement enabled, for escalations to the SRT and to initiate proactive customer support.

    Args:
        emergency_contact_list(List, optional): A list of email addresses and phone numbers that the Shield Response Team (SRT) can use to contact you if you have proactive engagement enabled, for escalations to the SRT and to initiate proactive customer support. If you have proactive engagement enabled, the contact list must include at least one phone number. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.emergency_contact_setting.update_multiple(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.emergency_contact_setting.update_multiple
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="shield",
        operation="update_emergency_contact_settings",
        op_kwargs={"EmergencyContactList": emergency_contact_list},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, cache_cluster_id: str = None, replication_group_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all available node types that you can scale your Redis cluster's or replication group's current node type. When you use the ModifyCacheCluster or ModifyReplicationGroup operations to scale your cluster or replication group, the value of the CacheNodeType parameter must be one of the node types returned by this operation.

    Args:
        cache_cluster_id(str, optional): The name of the cluster you want to scale up to a larger node instanced type. ElastiCache uses the cluster id to identify the current node type of this cluster and from that to create a list of node types you can scale up to.  You must provide a value for either the CacheClusterId or the ReplicationGroupId. . Defaults to None.
        replication_group_id(str, optional): The name of the replication group want to scale up to a larger node type. ElastiCache uses the replication group id to identify the current node type being used by this replication group, and from that to create a list of node types you can scale up to.  You must provide a value for either the CacheClusterId or the ReplicationGroupId. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.allowed_node_type_modification.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.allowed_node_type_modification.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="list_allowed_node_type_modifications",
        op_kwargs={
            "CacheClusterId": cache_cluster_id,
            "ReplicationGroupId": replication_group_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, distribution_config: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new web distribution. You create a CloudFront distribution to tell CloudFront where you want content to be delivered from, and the details about how to track and manage content delivery. Send a POST request to the /CloudFront API version/distribution/distribution ID resource.  When you update a distribution, there are more required fields than when you create a distribution. When you update your distribution by using UpdateDistribution, follow the steps included in the documentation to get the current configuration and then make your updates. This helps to make sure that you include all of the required fields. To view a summary, see Required Fields for Create Distribution and Update Distribution in the Amazon CloudFront Developer Guide.

    Args:
        distribution_config(Dict): The distribution's configuration information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.distribution.init.create(
                ctx, distribution_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.distribution.init.create distribution_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="create_distribution",
        op_kwargs={"DistributionConfig": distribution_config},
    )


async def delete(hub, ctx, id_: str, if_match: str = None) -> None:
    r"""
    **Autogenerated function**

    Delete a distribution.

    Args:
        id_(str): The distribution ID. .
        if_match(str, optional): The value of the ETag header that you received when you disabled the distribution. For example: E2QWRUHAPOMQZL. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.distribution.init.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.distribution.init.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="delete_distribution",
        op_kwargs={"Id": id_, "IfMatch": if_match},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Get the information about a distribution.

    Args:
        id_(str): The distribution's ID. If the ID is empty, an empty distribution configuration is returned.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.distribution.init.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.distribution.init.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="get_distribution",
        op_kwargs={"Id": id_},
    )


async def list_all(hub, ctx, marker: str = None, max_items: str = None) -> Dict:
    r"""
    **Autogenerated function**

    List CloudFront distributions.

    Args:
        marker(str, optional): Use this when paginating results to indicate where to begin in your list of distributions. The results include distributions in the list that occur after the marker. To get the next page of results, set the Marker to the value of the NextMarker from the current page's response (which is also the ID of the last distribution on that page). Defaults to None.
        max_items(str, optional): The maximum number of distributions you want in the response body. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.distribution.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.distribution.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="list_distributions",
        op_kwargs={"Marker": marker, "MaxItems": max_items},
    )


async def update(
    hub, ctx, distribution_config: Dict, id_: str, if_match: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the configuration for a web distribution.   When you update a distribution, there are more required fields than when you create a distribution. When you update your distribution by using this API action, follow the steps here to get the current configuration and then make your updates, to make sure that you include all of the required fields. To view a summary, see Required Fields for Create Distribution and Update Distribution in the Amazon CloudFront Developer Guide.  The update process includes getting the current distribution configuration, updating the XML document that is returned to make your changes, and then submitting an UpdateDistribution request to make the updates. For information about updating a distribution using the CloudFront console instead, see Creating a Distribution in the Amazon CloudFront Developer Guide.  To update a web distribution using the CloudFront API    Submit a GetDistributionConfig request to get the current configuration and an Etag header for the distribution.  If you update the distribution again, you must get a new Etag header.    Update the XML document that was returned in the response to your GetDistributionConfig request to include your changes.   When you edit the XML file, be aware of the following:   You must strip out the ETag parameter that is returned.   Additional fields are required when you update a distribution. There may be fields included in the XML file for features that you haven't configured for your distribution. This is expected and required to successfully update the distribution.   You can't change the value of CallerReference. If you try to change this value, CloudFront returns an IllegalUpdate error.    The new configuration replaces the existing configuration; the values that you specify in an UpdateDistribution request are not merged into your existing configuration. When you add, delete, or replace values in an element that allows multiple values (for example, CNAME), you must specify all of the values that you want to appear in the updated distribution. In addition, you must update the corresponding Quantity element.      Submit an UpdateDistribution request to update the configuration for your distribution:   In the request body, include the XML document that you updated in Step 2. The request body must include an XML document with a DistributionConfig element.   Set the value of the HTTP If-Match header to the value of the ETag header that CloudFront returned when you submitted the GetDistributionConfig request in Step 1.     Review the response to the UpdateDistribution request to confirm that the configuration was successfully updated.   Optional: Submit a GetDistribution request to confirm that your changes have propagated. When propagation is complete, the value of Status is Deployed.

    Args:
        distribution_config(Dict): The distribution's configuration information.
        id_(str): The distribution's id.
        if_match(str, optional): The value of the ETag header that you received when retrieving the distribution's configuration. For example: E2QWRUHAPOMQZL. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.distribution.init.update(
                ctx, distribution_config=value, id_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.distribution.init.update distribution_config=value, id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="update_distribution",
        op_kwargs={
            "DistributionConfig": distribution_config,
            "Id": id_,
            "IfMatch": if_match,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def remove(
    hub, ctx, resource: Dict, lf_tags: List, catalog_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Removes a tag from the resource. Only database, table, or tableWithColumns resource are allowed. To tag columns, use the column inclusion list in tableWithColumns to specify column input.

    Args:
        catalog_id(str, optional): The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your AWS Lake Formation environment. . Defaults to None.
        resource(Dict): The resource where you want to remove a tag.
        lf_tags(List): The tags to be removed from the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lakeformation.lf_tags.from_resource.remove(
                ctx, resource=value, lf_tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lakeformation.lf_tags.from_resource.remove resource=value, lf_tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lakeformation",
        operation="remove_lf_tags_from_resource",
        op_kwargs={"CatalogId": catalog_id, "Resource": resource, "LFTags": lf_tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, event_id: str, event_type_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified event. When you delete an event, Amazon Fraud Detector permanently deletes that event and the event data is no longer stored in Amazon Fraud Detector.

    Args:
        event_id(str): The ID of the event to delete.
        event_type_name(str): The name of the event type.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.event.init.delete(
                ctx, event_id=value, event_type_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.event.init.delete event_id=value, event_type_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="delete_event",
        op_kwargs={"eventId": event_id, "eventTypeName": event_type_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    application_id: str,
    max_items: int = None,
    next_token: str = None,
    semantic_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the list of applications nested in the containing application.

    Args:
        application_id(str): The Amazon Resource Name (ARN) of the application.
        max_items(int, optional): The total number of items to return. Defaults to None.
        next_token(str, optional): A token to specify where to start paginating. Defaults to None.
        semantic_version(str, optional): The semantic version of the application to get. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.serverlessrepo.application.dependency.list_all(
                ctx, application_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.serverlessrepo.application.dependency.list_all application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="serverlessrepo",
        operation="list_application_dependencies",
        op_kwargs={
            "ApplicationId": application_id,
            "MaxItems": max_items,
            "NextToken": next_token,
            "SemanticVersion": semantic_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, voice_connector_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the logging configuration details for the specified Amazon Chime Voice Connector. Shows whether SIP message logs are enabled for sending to Amazon CloudWatch Logs.

    Args:
        voice_connector_id(str): The Amazon Chime Voice Connector ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.logging_configuration.get(
                ctx, voice_connector_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.logging_configuration.get voice_connector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_voice_connector_logging_configuration",
        op_kwargs={"VoiceConnectorId": voice_connector_id},
    )


async def put(hub, ctx, voice_connector_id: str, logging_configuration: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Adds a logging configuration for the specified Amazon Chime Voice Connector. The logging configuration specifies whether SIP message logs are enabled for sending to Amazon CloudWatch Logs.

    Args:
        voice_connector_id(str): The Amazon Chime Voice Connector ID.
        logging_configuration(Dict): The logging configuration details to add.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.voice_connector.logging_configuration.put(
                ctx, voice_connector_id=value, logging_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.voice_connector.logging_configuration.put voice_connector_id=value, logging_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="put_voice_connector_logging_configuration",
        op_kwargs={
            "VoiceConnectorId": voice_connector_id,
            "LoggingConfiguration": logging_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(hub, ctx, cluster_identifier: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops logging information, such as queries and connection attempts, for the specified Amazon Redshift cluster.

    Args:
        cluster_identifier(str): The identifier of the cluster on which logging is to be stopped. Example: examplecluster .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.logging.init.disable(ctx, cluster_identifier=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.logging.init.disable cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="disable_logging",
        op_kwargs={"ClusterIdentifier": cluster_identifier},
    )


async def enable(
    hub, ctx, cluster_identifier: str, bucket_name: str, s3_key_prefix: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Starts logging information, such as queries and connection attempts, for the specified Amazon Redshift cluster.

    Args:
        cluster_identifier(str): The identifier of the cluster on which logging is to be started. Example: examplecluster .
        bucket_name(str): The name of an existing S3 bucket where the log files are to be stored. Constraints:   Must be in the same region as the cluster   The cluster must have read bucket and put object permissions  .
        s3_key_prefix(str, optional): The prefix applied to the log file names. Constraints:   Cannot exceed 512 characters   Cannot contain spaces( ), double quotes ("), single quotes ('), a backslash (\), or control characters. The hexadecimal codes for invalid characters are:    x00 to x20   x22   x27   x5c   x7f or larger    . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.logging.init.enable(
                ctx, cluster_identifier=value, bucket_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.logging.init.enable cluster_identifier=value, bucket_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="enable_logging",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "BucketName": bucket_name,
            "S3KeyPrefix": s3_key_prefix,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def get(hub, ctx, user_pool_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the user pool multi-factor authentication (MFA) configuration.

    Args:
        user_pool_id(str): The user pool ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.pool.mfa_config.get(ctx, user_pool_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.pool.mfa_config.get user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="get_user_pool_mfa_config",
        op_kwargs={"UserPoolId": user_pool_id},
    )


async def set_(
    hub,
    ctx,
    user_pool_id: str,
    sms_mfa_configuration: Dict = None,
    software_token_mfa_configuration: Dict = None,
    mfa_configuration: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Set the user pool multi-factor authentication (MFA) configuration.  This action might generate an SMS text message. Starting June 1, 2021, U.S. telecom carriers require that you register an origination phone number before you can send SMS messages to U.S. phone numbers. If you use SMS text messages in Amazon Cognito, you must register a phone number with Amazon Pinpoint. Cognito will use the the registered number automatically. Otherwise, Cognito users that must receive SMS messages might be unable to sign up, activate their accounts, or sign in. If you have never used SMS text messages with Amazon Cognito or any other Amazon Web Service, Amazon SNS might place your account in SMS sandbox. In  sandbox mode , you’ll have limitations, such as sending messages to only verified phone numbers. After testing in the sandbox environment, you can move out of the SMS sandbox and into production. For more information, see  SMS message settings for Cognito User Pools in the Amazon Cognito Developer Guide.

    Args:
        user_pool_id(str): The user pool ID.
        sms_mfa_configuration(Dict, optional): The SMS text message MFA configuration. Defaults to None.
        software_token_mfa_configuration(Dict, optional): The software token MFA configuration. Defaults to None.
        mfa_configuration(str, optional): The MFA configuration. Users who don't have an MFA factor set up won't be able to sign-in if you set the MfaConfiguration value to ‘ON’. See Adding Multi-Factor Authentication (MFA) to a User Pool to learn more. Valid values include:    OFF MFA will not be used for any users.    ON MFA is required for all users to sign in.    OPTIONAL MFA will be required only for individual users who have an MFA factor enabled.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.user.pool.mfa_config.set(ctx, user_pool_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.user.pool.mfa_config.set user_pool_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="set_user_pool_mfa_config",
        op_kwargs={
            "UserPoolId": user_pool_id,
            "SmsMfaConfiguration": sms_mfa_configuration,
            "SoftwareTokenMfaConfiguration": software_token_mfa_configuration,
            "MfaConfiguration": mfa_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(hub, ctx, resource_id: str, tag_option_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates the specified TagOption from the specified resource.

    Args:
        resource_id(str): The resource identifier.
        tag_option_id(str): The TagOption identifier.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.tag_option.from_resource.disassociate(
                ctx, resource_id=value, tag_option_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.tag_option.from_resource.disassociate resource_id=value, tag_option_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="disassociate_tag_option_from_resource",
        op_kwargs={"ResourceId": resource_id, "TagOptionId": tag_option_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    access_policy_identity: Dict,
    access_policy_resource: Dict,
    access_policy_permission: str,
    client_token: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an access policy that grants the specified identity (Amazon Web Services SSO user, Amazon Web Services SSO group, or IAM user) access to the specified IoT SiteWise Monitor portal or project resource.

    Args:
        access_policy_identity(Dict): The identity for this access policy. Choose an Amazon Web Services SSO user, an Amazon Web Services SSO group, or an IAM user.
        access_policy_resource(Dict): The IoT SiteWise Monitor resource for this access policy. Choose either a portal or a project.
        access_policy_permission(str): The permission level for this access policy. Note that a project ADMINISTRATOR is also known as a project owner.
        client_token(str, optional): A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required. Defaults to None.
        tags(Dict, optional): A list of key-value pairs that contain metadata for the access policy. For more information, see Tagging your IoT SiteWise resources in the IoT SiteWise User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.access_policy.create(
                ctx,
                access_policy_identity=value,
                access_policy_resource=value,
                access_policy_permission=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.access_policy.create access_policy_identity=value, access_policy_resource=value, access_policy_permission=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="create_access_policy",
        op_kwargs={
            "accessPolicyIdentity": access_policy_identity,
            "accessPolicyResource": access_policy_resource,
            "accessPolicyPermission": access_policy_permission,
            "clientToken": client_token,
            "tags": tags,
        },
    )


async def delete(hub, ctx, access_policy_id: str, client_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an access policy that grants the specified identity access to the specified IoT SiteWise Monitor resource. You can use this operation to revoke access to an IoT SiteWise Monitor resource.

    Args:
        access_policy_id(str): The ID of the access policy to be deleted.
        client_token(str, optional): A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.access_policy.delete(ctx, access_policy_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.access_policy.delete access_policy_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="delete_access_policy",
        op_kwargs={"accessPolicyId": access_policy_id, "clientToken": client_token},
    )


async def describe(hub, ctx, access_policy_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes an access policy, which specifies an identity's access to an IoT SiteWise Monitor portal or project.

    Args:
        access_policy_id(str): The ID of the access policy.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.access_policy.describe(ctx, access_policy_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.access_policy.describe access_policy_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="describe_access_policy",
        op_kwargs={"accessPolicyId": access_policy_id},
    )


async def list_all(
    hub,
    ctx,
    identity_type: str = None,
    identity_id: str = None,
    resource_type: str = None,
    resource_id: str = None,
    iam_arn: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a paginated list of access policies for an identity (an Amazon Web Services SSO user, an Amazon Web Services SSO group, or an IAM user) or an IoT SiteWise Monitor resource (a portal or project).

    Args:
        identity_type(str, optional): The type of identity (Amazon Web Services SSO user, Amazon Web Services SSO group, or IAM user). This parameter is required if you specify identityId. Defaults to None.
        identity_id(str, optional): The ID of the identity. This parameter is required if you specify USER or GROUP for identityType. Defaults to None.
        resource_type(str, optional): The type of resource (portal or project). This parameter is required if you specify resourceId. Defaults to None.
        resource_id(str, optional): The ID of the resource. This parameter is required if you specify resourceType. Defaults to None.
        iam_arn(str, optional): The ARN of the IAM user. For more information, see IAM ARNs in the IAM User Guide. This parameter is required if you specify IAM for identityType. Defaults to None.
        next_token(str, optional): The token to be used for the next set of paginated results. Defaults to None.
        max_results(int, optional): The maximum number of results to return for each paginated request. Default: 50. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.access_policy.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.access_policy.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="list_access_policies",
        op_kwargs={
            "identityType": identity_type,
            "identityId": identity_id,
            "resourceType": resource_type,
            "resourceId": resource_id,
            "iamArn": iam_arn,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    access_policy_id: str,
    access_policy_identity: Dict,
    access_policy_resource: Dict,
    access_policy_permission: str,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing access policy that specifies an identity's access to an IoT SiteWise Monitor portal or project resource.

    Args:
        access_policy_id(str): The ID of the access policy.
        access_policy_identity(Dict): The identity for this access policy. Choose an Amazon Web Services SSO user, an Amazon Web Services SSO group, or an IAM user.
        access_policy_resource(Dict): The IoT SiteWise Monitor resource for this access policy. Choose either a portal or a project.
        access_policy_permission(str): The permission level for this access policy. Note that a project ADMINISTRATOR is also known as a project owner.
        client_token(str, optional): A unique case-sensitive identifier that you can provide to ensure the idempotency of the request. Don't reuse this client token if a new idempotent request is required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotsitewise.access_policy.update(
                ctx,
                access_policy_id=value,
                access_policy_identity=value,
                access_policy_resource=value,
                access_policy_permission=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotsitewise.access_policy.update access_policy_id=value, access_policy_identity=value, access_policy_resource=value, access_policy_permission=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotsitewise",
        operation="update_access_policy",
        op_kwargs={
            "accessPolicyId": access_policy_id,
            "accessPolicyIdentity": access_policy_identity,
            "accessPolicyResource": access_policy_resource,
            "accessPolicyPermission": access_policy_permission,
            "clientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    channel_name: str,
    channel_storage: Dict = None,
    retention_period: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Used to create a channel. A channel collects data from an MQTT topic and archives the raw, unprocessed messages before publishing the data to a pipeline.

    Args:
        channel_name(str): The name of the channel.
        channel_storage(Dict, optional): Where channel data is stored. You can choose one of serviceManagedS3 or customerManagedS3 storage. If not specified, the default is serviceManagedS3. You can't change this storage option after the channel is created. Defaults to None.
        retention_period(Dict, optional): How long, in days, message data is kept for the channel. When customerManagedS3 storage is selected, this parameter is ignored. Defaults to None.
        tags(List, optional): Metadata which can be used to manage the channel. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.channel.init.create(ctx, channel_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.channel.init.create channel_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="create_channel",
        op_kwargs={
            "channelName": channel_name,
            "channelStorage": channel_storage,
            "retentionPeriod": retention_period,
            "tags": tags,
        },
    )


async def delete(hub, ctx, channel_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified channel.

    Args:
        channel_name(str): The name of the channel to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.channel.init.delete(ctx, channel_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.channel.init.delete channel_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="delete_channel",
        op_kwargs={"channelName": channel_name},
    )


async def describe(
    hub, ctx, channel_name: str, include_statistics: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a channel.

    Args:
        channel_name(str): The name of the channel whose information is retrieved.
        include_statistics(bool, optional): If true, additional statistical information about the channel is included in the response. This feature can't be used with a channel whose S3 storage is customer-managed. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.channel.init.describe(ctx, channel_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.channel.init.describe channel_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="describe_channel",
        op_kwargs={
            "channelName": channel_name,
            "includeStatistics": include_statistics,
        },
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of channels.

    Args:
        next_token(str, optional): The token for the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in this request. The default value is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.channel.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.channel.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="list_channels",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub,
    ctx,
    channel_name: str,
    channel_storage: Dict = None,
    retention_period: Dict = None,
) -> None:
    r"""
    **Autogenerated function**

    Used to update the settings of a channel.

    Args:
        channel_name(str): The name of the channel to be updated.
        channel_storage(Dict, optional): Where channel data is stored. You can choose one of serviceManagedS3 or customerManagedS3 storage. If not specified, the default is serviceManagedS3. You can't change this storage option after the channel is created. Defaults to None.
        retention_period(Dict, optional): How long, in days, message data is kept for the channel. The retention period can't be updated if the channel's Amazon S3 storage is customer-managed. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.channel.init.update(ctx, channel_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.channel.init.update channel_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="update_channel",
        op_kwargs={
            "channelName": channel_name,
            "channelStorage": channel_storage,
            "retentionPeriod": retention_period,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, device_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the devices available in Amazon Braket.

    Args:
        device_arn(str): The ARN of the device to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.braket.device.get(ctx, device_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.braket.device.get device_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="braket",
        operation="get_device",
        op_kwargs={"deviceArn": device_arn},
    )


async def search(
    hub, ctx, filters: List, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Searches for devices using the specified filters.

    Args:
        filters(List): The filter values to use to search for a device.
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.
        next_token(str, optional): A token used for pagination of results returned in the response. Use the token returned from the previous request continue results where the previous request ended. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.braket.device.search(ctx, filters=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.braket.device.search filters=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="braket",
        operation="search_devices",
        op_kwargs={
            "filters": filters,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    backup_plan: Dict,
    backup_plan_tags: Dict = None,
    creator_request_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a backup plan using a backup plan name and backup rules. A backup plan is a document that contains information that AWS Backup uses to schedule tasks that create recovery points for resources. If you call CreateBackupPlan with a plan that already exists, an AlreadyExistsException is returned.

    Args:
        backup_plan(Dict): Specifies the body of a backup plan. Includes a BackupPlanName and one or more sets of Rules.
        backup_plan_tags(Dict, optional): To help organize your resources, you can assign your own metadata to the resources that you create. Each tag is a key-value pair. The specified tags are assigned to all backups created with this plan. Defaults to None.
        creator_request_id(str, optional): Identifies the request and allows failed requests to be retried without the risk of running the operation twice. If the request includes a CreatorRequestId that matches an existing backup plan, that plan is returned. This parameter is optional. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.plan.init.create(ctx, backup_plan=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.plan.init.create backup_plan=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="create_backup_plan",
        op_kwargs={
            "BackupPlan": backup_plan,
            "BackupPlanTags": backup_plan_tags,
            "CreatorRequestId": creator_request_id,
        },
    )


async def delete(hub, ctx, backup_plan_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a backup plan. A backup plan can only be deleted after all associated selections of resources have been deleted. Deleting a backup plan deletes the current version of a backup plan. Previous versions, if any, will still exist.

    Args:
        backup_plan_id(str): Uniquely identifies a backup plan.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.plan.init.delete(ctx, backup_plan_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.plan.init.delete backup_plan_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="delete_backup_plan",
        op_kwargs={"BackupPlanId": backup_plan_id},
    )


async def get(hub, ctx, backup_plan_id: str, version_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns BackupPlan details for the specified BackupPlanId. The details are the body of a backup plan in JSON format, in addition to plan metadata.

    Args:
        backup_plan_id(str): Uniquely identifies a backup plan.
        version_id(str, optional): Unique, randomly generated, Unicode, UTF-8 encoded strings that are at most 1,024 bytes long. Version IDs cannot be edited. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.plan.init.get(ctx, backup_plan_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.plan.init.get backup_plan_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="get_backup_plan",
        op_kwargs={"BackupPlanId": backup_plan_id, "VersionId": version_id},
    )


async def list_all(
    hub,
    ctx,
    next_token: str = None,
    max_results: int = None,
    include_deleted: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of existing backup plans for an authenticated account. The list is populated only if the advanced option is set for the backup plan. The list contains information such as Amazon Resource Names (ARNs), plan IDs, creation and deletion dates, version IDs, plan names, and creator request IDs.

    Args:
        next_token(str, optional): The next item following a partial list of returned items. For example, if a request is made to return maxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token. Defaults to None.
        max_results(int, optional): The maximum number of items to be returned. Defaults to None.
        include_deleted(bool, optional): A Boolean value with a default value of FALSE that returns deleted backup plans when set to TRUE. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.plan.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.plan.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="list_backup_plans",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "IncludeDeleted": include_deleted,
        },
    )


async def update(hub, ctx, backup_plan_id: str, backup_plan: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing backup plan identified by its backupPlanId with the input document in JSON format. The new version is uniquely identified by a VersionId.

    Args:
        backup_plan_id(str): Uniquely identifies a backup plan.
        backup_plan(Dict): Specifies the body of a backup plan. Includes a BackupPlanName and one or more sets of Rules.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.backup.backup.plan.init.update(
                ctx, backup_plan_id=value, backup_plan=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.backup.backup.plan.init.update backup_plan_id=value, backup_plan=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="backup",
        operation="update_backup_plan",
        op_kwargs={"BackupPlanId": backup_plan_id, "BackupPlan": backup_plan},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, name: str, block_address: Dict, digest_tip_address: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a block object at a specified address in a journal. Also returns a proof of the specified block for verification if DigestTipAddress is provided. For information about the data contents in a block, see Journal contents in the Amazon QLDB Developer Guide. If the specified ledger doesn't exist or is in DELETING status, then throws ResourceNotFoundException. If the specified ledger is in CREATING status, then throws ResourcePreconditionNotMetException. If no block exists with the specified address, then throws InvalidParameterException.

    Args:
        name(str): The name of the ledger.
        block_address(Dict): The location of the block that you want to request. An address is an Amazon Ion structure that has two fields: strandId and sequenceNo. For example: {strandId:"BlFTjlSXze9BIh1KOszcE3",sequenceNo:14}.
        digest_tip_address(Dict, optional): The latest block location covered by the digest for which to request a proof. An address is an Amazon Ion structure that has two fields: strandId and sequenceNo. For example: {strandId:"BlFTjlSXze9BIh1KOszcE3",sequenceNo:49}. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.qldb.block.get(ctx, name=value, block_address=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.qldb.block.get name=value, block_address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="qldb",
        operation="get_block",
        op_kwargs={
            "Name": name,
            "BlockAddress": block_address,
            "DigestTipAddress": digest_tip_address,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def download(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Downloads the default SSH key pair from the user's account.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.default_key_pair.download(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.default_key_pair.download
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="download_default_key_pair",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    scheduled_instance_ids: List = None,
    slot_start_time_range: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified Scheduled Instances or all your Scheduled Instances.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        filters(List, optional): The filters.    availability-zone - The Availability Zone (for example, us-west-2a).    instance-type - The instance type (for example, c4.large).    network-platform - The network platform (EC2-Classic or EC2-VPC).    platform - The platform (Linux/UNIX or Windows).  . Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. This value can be between 5 and 300. The default value is 100. To retrieve the remaining results, make another call with the returned NextToken value. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.
        scheduled_instance_ids(List, optional): The Scheduled Instance IDs. Defaults to None.
        slot_start_time_range(Dict, optional): The time period for the first schedule to start. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.scheduled_instance.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.scheduled_instance.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_scheduled_instances",
        op_kwargs={
            "DryRun": dry_run,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "ScheduledInstanceIds": scheduled_instance_ids,
            "SlotStartTimeRange": slot_start_time_range,
        },
    )


async def purchase(
    hub, ctx, purchase_requests: List, client_token: str = None, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Purchases the Scheduled Instances with the specified schedule. Scheduled Instances enable you to purchase Amazon EC2 compute capacity by the hour for a one-year term. Before you can purchase a Scheduled Instance, you must call DescribeScheduledInstanceAvailability to check for available schedules and obtain a purchase token. After you purchase a Scheduled Instance, you must call RunScheduledInstances during each scheduled time period. After you purchase a Scheduled Instance, you can't cancel, modify, or resell your purchase.

    Args:
        client_token(str, optional): Unique, case-sensitive identifier that ensures the idempotency of the request. For more information, see Ensuring Idempotency. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        purchase_requests(List): The purchase requests.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.scheduled_instance.init.purchase(
                ctx, purchase_requests=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.scheduled_instance.init.purchase purchase_requests=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="purchase_scheduled_instances",
        op_kwargs={
            "ClientToken": client_token,
            "DryRun": dry_run,
            "PurchaseRequests": purchase_requests,
        },
    )


async def run(
    hub,
    ctx,
    launch_specification: Dict,
    scheduled_instance_id: str,
    client_token: str = None,
    dry_run: bool = None,
    instance_count: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Launches the specified Scheduled Instances. Before you can launch a Scheduled Instance, you must purchase it and obtain an identifier using PurchaseScheduledInstances. You must launch a Scheduled Instance during its scheduled time period. You can't stop or reboot a Scheduled Instance, but you can terminate it as needed. If you terminate a Scheduled Instance before the current scheduled time period ends, you can launch it again after a few minutes. For more information, see Scheduled Instances in the Amazon EC2 User Guide.

    Args:
        client_token(str, optional): Unique, case-sensitive identifier that ensures the idempotency of the request. For more information, see Ensuring Idempotency. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        instance_count(int, optional): The number of instances. Default: 1. Defaults to None.
        launch_specification(Dict): The launch specification. You must match the instance type, Availability Zone, network, and platform of the schedule that you purchased.
        scheduled_instance_id(str): The Scheduled Instance ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.scheduled_instance.init.run(
                ctx, launch_specification=value, scheduled_instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.scheduled_instance.init.run launch_specification=value, scheduled_instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="run_scheduled_instances",
        op_kwargs={
            "ClientToken": client_token,
            "DryRun": dry_run,
            "InstanceCount": instance_count,
            "LaunchSpecification": launch_specification,
            "ScheduledInstanceId": scheduled_instance_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, policy_input_list: List) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of all of the context keys referenced in the input policies. The policies are supplied as a list of one or more strings. To get the context keys from policies associated with an IAM user, group, or role, use GetContextKeysForPrincipalPolicy. Context keys are variables maintained by Amazon Web Services and its services that provide details about the context of an API query request. Context keys can be evaluated by testing against a value specified in an IAM policy. Use GetContextKeysForCustomPolicy to understand what key names and values you must supply when you call SimulateCustomPolicy. Note that all parameters are shown in unencoded form here for clarity but must be URL encoded to be included as a part of a real HTML request.

    Args:
        policy_input_list(List): A list of policies for which you want the list of context keys referenced in those policies. Each document is specified as a string containing the complete, valid JSON text of an IAM policy. The regex pattern used to validate this parameter is a string of characters consisting of the following:   Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range   The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)   The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.context_keys_for_.custom_policy.get(
                ctx, policy_input_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.context_keys_for_.custom_policy.get policy_input_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="get_context_keys_for_custom_policy",
        op_kwargs={"PolicyInputList": policy_input_list},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    endpoint_name: str,
    model_arn: str,
    desired_inference_units: int,
    client_request_token: str = None,
    tags: List = None,
    data_access_role_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a model-specific endpoint for synchronous inference for a previously trained custom model

    Args:
        endpoint_name(str): This is the descriptive suffix that becomes part of the EndpointArn used for all subsequent requests to this resource. .
        model_arn(str): The Amazon Resource Number (ARN) of the model to which the endpoint will be attached.
        desired_inference_units(int):  The desired number of inference units to be used by the model using this endpoint. Each inference unit represents of a throughput of 100 characters per second.
        client_request_token(str, optional): An idempotency token provided by the customer. If this token matches a previous endpoint creation request, Amazon Comprehend will not return a ResourceInUseException. . Defaults to None.
        tags(List, optional): Tags associated with the endpoint being created. A tag is a key-value pair that adds metadata to the endpoint. For example, a tag with "Sales" as the key might be added to an endpoint to indicate its use by the sales department. . Defaults to None.
        data_access_role_arn(str, optional): The Amazon Resource Name (ARN) of the AWS identity and Access Management (IAM) role that grants Amazon Comprehend read access to trained custom models encrypted with a customer managed key (ModelKmsKeyId). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.endpoint.create(
                ctx, endpoint_name=value, model_arn=value, desired_inference_units=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.endpoint.create endpoint_name=value, model_arn=value, desired_inference_units=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="create_endpoint",
        op_kwargs={
            "EndpointName": endpoint_name,
            "ModelArn": model_arn,
            "DesiredInferenceUnits": desired_inference_units,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
            "DataAccessRoleArn": data_access_role_arn,
        },
    )


async def delete(hub, ctx, endpoint_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a model-specific endpoint for a previously-trained custom model. All endpoints must be deleted in order for the model to be deleted.

    Args:
        endpoint_arn(str): The Amazon Resource Number (ARN) of the endpoint being deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.endpoint.delete(ctx, endpoint_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.endpoint.delete endpoint_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="delete_endpoint",
        op_kwargs={"EndpointArn": endpoint_arn},
    )


async def describe(hub, ctx, endpoint_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the properties associated with a specific endpoint. Use this operation to get the status of an endpoint.

    Args:
        endpoint_arn(str): The Amazon Resource Number (ARN) of the endpoint being described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.endpoint.describe(ctx, endpoint_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.endpoint.describe endpoint_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="describe_endpoint",
        op_kwargs={"EndpointArn": endpoint_arn},
    )


async def list_all(
    hub, ctx, filter_: Dict = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of all existing endpoints that you've created.

    Args:
        filter_(Dict, optional): Filters the endpoints that are returned. You can filter endpoints on their name, model, status, or the date and time that they were created. You can only set one filter at a time. . Defaults to None.
        next_token(str, optional): Identifies the next page of results to return. Defaults to None.
        max_results(int, optional): The maximum number of results to return in each page. The default is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.endpoint.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.endpoint.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="list_endpoints",
        op_kwargs={
            "Filter": filter_,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(hub, ctx, endpoint_arn: str, desired_inference_units: int) -> Dict:
    r"""
    **Autogenerated function**

    Updates information about the specified endpoint.

    Args:
        endpoint_arn(str): The Amazon Resource Number (ARN) of the endpoint being updated.
        desired_inference_units(int):  The desired number of inference units to be used by the model using this endpoint. Each inference unit represents of a throughput of 100 characters per second.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.endpoint.update(
                ctx, endpoint_arn=value, desired_inference_units=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.endpoint.update endpoint_arn=value, desired_inference_units=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="update_endpoint",
        op_kwargs={
            "EndpointArn": endpoint_arn,
            "DesiredInferenceUnits": desired_inference_units,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    domain: str,
    repository: str,
    format_: str,
    package: str,
    package_version: str,
    domain_owner: str = None,
    namespace: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Gets the readme file or descriptive text for a package version. For packages that do not contain a readme file, CodeArtifact extracts a description from a metadata file. For example, from the <description> element in the pom.xml file of a Maven package.   The returned text might contain formatting. For example, it might contain formatting for Markdown or reStructuredText.

    Args:
        domain(str):  The name of the domain that contains the repository that contains the package version with the requested readme file. .
        domain_owner(str, optional):  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. . Defaults to None.
        repository(str):  The repository that contains the package with the requested readme file. .
        format_(str):  A format that specifies the type of the package version with the requested readme file. The valid values are:     npm     pypi     maven   .
        namespace(str, optional):  The namespace of the package. The package component that specifies its namespace depends on its type. For example:     The namespace of a Maven package is its groupId.     The namespace of an npm package is its scope.     A Python package does not contain a corresponding component, so Python packages do not have a namespace.   . Defaults to None.
        package(str):  The name of the package version that contains the requested readme file. .
        package_version(str):  A string that contains the package version (for example, 3.5.2). .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeartifact.package.version.readme.get(
                ctx,
                domain=value,
                repository=value,
                format_=value,
                package=value,
                package_version=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeartifact.package.version.readme.get domain=value, repository=value, format_=value, package=value, package_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeartifact",
        operation="get_package_version_readme",
        op_kwargs={
            "domain": domain,
            "domainOwner": domain_owner,
            "repository": repository,
            "format": format_,
            "namespace": namespace,
            "package": package,
            "packageVersion": package_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def restore(hub, ctx, snapshot_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Restores a directory using an existing directory snapshot. When you restore a directory from a snapshot, any changes made to the directory after the snapshot date are overwritten. This action returns as soon as the restore operation is initiated. You can monitor the progress of the restore operation by calling the DescribeDirectories operation with the directory identifier. When the DirectoryDescription.Stage value changes to Active, the restore operation is complete.

    Args:
        snapshot_id(str): The identifier of the snapshot to restore from.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.from_snapshot.restore(ctx, snapshot_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.from_snapshot.restore snapshot_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="restore_from_snapshot",
        op_kwargs={"SnapshotId": snapshot_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, contact_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels a contact with a specified contact ID.

    Args:
        contact_id(str): UUID of a contact.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.contact.cancel(ctx, contact_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.contact.cancel contact_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="cancel_contact",
        op_kwargs={"contactId": contact_id},
    )


async def describe(hub, ctx, contact_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes an existing contact.

    Args:
        contact_id(str): UUID of a contact.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.contact.describe(ctx, contact_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.contact.describe contact_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="describe_contact",
        op_kwargs={"contactId": contact_id},
    )


async def list_all(
    hub,
    ctx,
    end_time: str,
    start_time: str,
    status_list: List,
    ground_station: str = None,
    max_results: int = None,
    mission_profile_arn: str = None,
    next_token: str = None,
    satellite_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of contacts. If statusList contains AVAILABLE, the request must include groundStation, missionprofileArn, and satelliteArn.

    Args:
        end_time(str): End time of a contact.
        ground_station(str, optional): Name of a ground station. Defaults to None.
        max_results(int, optional): Maximum number of contacts returned. Defaults to None.
        mission_profile_arn(str, optional): ARN of a mission profile. Defaults to None.
        next_token(str, optional): Next token returned in the request of a previous ListContacts call. Used to get the next page of results. Defaults to None.
        satellite_arn(str, optional): ARN of a satellite. Defaults to None.
        start_time(str): Start time of a contact.
        status_list(List): Status of a contact reservation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.contact.list_all(
                ctx, end_time=value, start_time=value, status_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.contact.list_all end_time=value, start_time=value, status_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="list_contacts",
        op_kwargs={
            "endTime": end_time,
            "groundStation": ground_station,
            "maxResults": max_results,
            "missionProfileArn": mission_profile_arn,
            "nextToken": next_token,
            "satelliteArn": satellite_arn,
            "startTime": start_time,
            "statusList": status_list,
        },
    )


async def reserve(
    hub,
    ctx,
    end_time: str,
    ground_station: str,
    mission_profile_arn: str,
    satellite_arn: str,
    start_time: str,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Reserves a contact using specified parameters.

    Args:
        end_time(str): End time of a contact.
        ground_station(str): Name of a ground station.
        mission_profile_arn(str): ARN of a mission profile.
        satellite_arn(str): ARN of a satellite.
        start_time(str): Start time of a contact.
        tags(Dict, optional): Tags assigned to a contact. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.contact.reserve(
                ctx,
                end_time=value,
                ground_station=value,
                mission_profile_arn=value,
                satellite_arn=value,
                start_time=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.contact.reserve end_time=value, ground_station=value, mission_profile_arn=value, satellite_arn=value, start_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="reserve_contact",
        op_kwargs={
            "endTime": end_time,
            "groundStation": ground_station,
            "missionProfileArn": mission_profile_arn,
            "satelliteArn": satellite_arn,
            "startTime": start_time,
            "tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def terminate(
    hub, ctx, instance_id: str, should_decrement_desired_capacity: bool
) -> Dict:
    r"""
    **Autogenerated function**

    Terminates the specified instance and optionally adjusts the desired group size. This operation cannot be called on instances in a warm pool. This call simply makes a termination request. The instance is not terminated immediately. When an instance is terminated, the instance status changes to terminated. You can't connect to or start an instance after you've terminated it. If you do not specify the option to decrement the desired capacity, Amazon EC2 Auto Scaling launches instances to replace the ones that are terminated.  By default, Amazon EC2 Auto Scaling balances instances across all Availability Zones. If you decrement the desired capacity, your Auto Scaling group can become unbalanced between Availability Zones. Amazon EC2 Auto Scaling tries to rebalance the group, and rebalancing might terminate instances in other zones. For more information, see Rebalancing activities in the Amazon EC2 Auto Scaling User Guide.

    Args:
        instance_id(str): The ID of the instance.
        should_decrement_desired_capacity(bool): Indicates whether terminating the instance also decrements the size of the Auto Scaling group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.instance.in_auto_scaling_group.terminate(
                ctx, instance_id=value, should_decrement_desired_capacity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.instance.in_auto_scaling_group.terminate instance_id=value, should_decrement_desired_capacity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="terminate_instance_in_auto_scaling_group",
        op_kwargs={
            "InstanceId": instance_id,
            "ShouldDecrementDesiredCapacity": should_decrement_desired_capacity,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    workforce_name: str,
    cognito_config: Dict = None,
    oidc_config: Dict = None,
    source_ip_config: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Use this operation to create a workforce. This operation will return an error if a workforce already exists in the Amazon Web Services Region that you specify. You can only create one workforce in each Amazon Web Services Region per Amazon Web Services account. If you want to create a new workforce in an Amazon Web Services Region where a workforce already exists, use the API operation to delete the existing workforce and then use CreateWorkforce to create a new workforce. To create a private workforce using Amazon Cognito, you must specify a Cognito user pool in CognitoConfig. You can also create an Amazon Cognito workforce using the Amazon SageMaker console. For more information, see  Create a Private Workforce (Amazon Cognito). To create a private workforce using your own OIDC Identity Provider (IdP), specify your IdP configuration in OidcConfig. Your OIDC IdP must support groups because groups are used by Ground Truth and Amazon A2I to create work teams. For more information, see  Create a Private Workforce (OIDC IdP).

    Args:
        cognito_config(Dict, optional): Use this parameter to configure an Amazon Cognito private workforce. A single Cognito workforce is created using and corresponds to a single  Amazon Cognito user pool. Do not use OidcConfig if you specify values for CognitoConfig. Defaults to None.
        oidc_config(Dict, optional): Use this parameter to configure a private workforce using your own OIDC Identity Provider. Do not use CognitoConfig if you specify values for OidcConfig. Defaults to None.
        source_ip_config(Dict, optional): A list of IP address ranges (CIDRs). Used to create an allow list of IP addresses for a private workforce. Workers will only be able to login to their worker portal from an IP address within this range. By default, a workforce isn't restricted to specific IP addresses. Defaults to None.
        workforce_name(str): The name of the private workforce.
        tags(List, optional): An array of key-value pairs that contain metadata to help you categorize and organize our workforce. Each tag consists of a key and a value, both of which you define. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.workforce.create(ctx, workforce_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.workforce.create workforce_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_workforce",
        op_kwargs={
            "CognitoConfig": cognito_config,
            "OidcConfig": oidc_config,
            "SourceIpConfig": source_ip_config,
            "WorkforceName": workforce_name,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, workforce_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Use this operation to delete a workforce. If you want to create a new workforce in an Amazon Web Services Region where a workforce already exists, use this operation to delete the existing workforce and then use to create a new workforce.  If a private workforce contains one or more work teams, you must use the operation to delete all work teams before you delete the workforce. If you try to delete a workforce that contains one or more work teams, you will recieve a ResourceInUse error.

    Args:
        workforce_name(str): The name of the workforce.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.workforce.delete(ctx, workforce_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.workforce.delete workforce_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_workforce",
        op_kwargs={"WorkforceName": workforce_name},
    )


async def describe(hub, ctx, workforce_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists private workforce information, including workforce name, Amazon Resource Name (ARN), and, if applicable, allowed IP address ranges (CIDRs). Allowable IP address ranges are the IP addresses that workers can use to access tasks.   This operation applies only to private workforces.

    Args:
        workforce_name(str): The name of the private workforce whose access you want to restrict. WorkforceName is automatically set to default when a workforce is created and cannot be modified. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.workforce.describe(ctx, workforce_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.workforce.describe workforce_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_workforce",
        op_kwargs={"WorkforceName": workforce_name},
    )


async def list_all(
    hub,
    ctx,
    sort_by: str = None,
    sort_order: str = None,
    name_contains: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Use this operation to list all private and vendor workforces in an Amazon Web Services Region. Note that you can only have one private workforce per Amazon Web Services Region.

    Args:
        sort_by(str, optional): Sort workforces using the workforce name or creation date. Defaults to None.
        sort_order(str, optional): Sort workforces in ascending or descending order. Defaults to None.
        name_contains(str, optional): A filter you can use to search for workforces using part of the workforce name. Defaults to None.
        next_token(str, optional): A token to resume pagination. Defaults to None.
        max_results(int, optional): The maximum number of workforces returned in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.workforce.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.workforce.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_workforces",
        op_kwargs={
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NameContains": name_contains,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    workforce_name: str,
    source_ip_config: Dict = None,
    oidc_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Use this operation to update your workforce. You can use this operation to require that workers use specific IP addresses to work on tasks and to update your OpenID Connect (OIDC) Identity Provider (IdP) workforce configuration.  Use SourceIpConfig to restrict worker access to tasks to a specific range of IP addresses. You specify allowed IP addresses by creating a list of up to ten CIDRs. By default, a workforce isn't restricted to specific IP addresses. If you specify a range of IP addresses, workers who attempt to access tasks using any IP address outside the specified range are denied and get a Not Found error message on the worker portal. Use OidcConfig to update the configuration of a workforce created using your own OIDC IdP.   You can only update your OIDC IdP configuration when there are no work teams associated with your workforce. You can delete work teams using the operation.  After restricting access to a range of IP addresses or updating your OIDC IdP configuration with this operation, you can view details about your update workforce using the operation.  This operation only applies to private workforces.

    Args:
        workforce_name(str): The name of the private workforce that you want to update. You can find your workforce name by using the operation.
        source_ip_config(Dict, optional): A list of one to ten worker IP address ranges (CIDRs) that can be used to access tasks assigned to this workforce. Maximum: Ten CIDR values. Defaults to None.
        oidc_config(Dict, optional): Use this parameter to update your OIDC Identity Provider (IdP) configuration for a workforce made using your own IdP. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.workforce.update(ctx, workforce_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.workforce.update workforce_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_workforce",
        op_kwargs={
            "WorkforceName": workforce_name,
            "SourceIpConfig": source_ip_config,
            "OidcConfig": oidc_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, rules_package_arns: List, locale: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes the rules packages that are specified by the ARNs of the rules packages.

    Args:
        rules_package_arns(List): The ARN that specifies the rules package that you want to describe.
        locale(str, optional): The locale that you want to translate a rules package description into. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.rule_package.describe_all(
                ctx, rules_package_arns=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.rule_package.describe_all rules_package_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="describe_rules_packages",
        op_kwargs={"rulesPackageArns": rules_package_arns, "locale": locale},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all available Amazon Inspector rules packages.

    Args:
        next_token(str, optional): You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the ListRulesPackages action. Subsequent calls to the action fill nextToken in the request with the value of NextToken from the previous response to continue listing data. Defaults to None.
        max_results(int, optional): You can use this parameter to indicate the maximum number of items you want in the response. The default value is 10. The maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.rule_package.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.rule_package.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="list_rules_packages",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, game_session_id: str, player_id: str, player_data: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Reserves an open player slot in a game session for a player. New player sessions can be created in any game session with an open slot that is in ACTIVE status and has a player creation policy of ACCEPT_ALL. You can add a group of players to a game session with CreatePlayerSessions.  To create a player session, specify a game session ID, player ID, and optionally a set of player data.  If successful, a slot is reserved in the game session for the player and a new PlayerSession object is returned with a player session ID. The player references the player session ID when sending a connection request to the game session, and the game server can use it to validate the player reservation with the GameLift service. Player sessions cannot be updated.   Available in Amazon GameLift Local.   Related actions   CreatePlayerSession | CreatePlayerSessions | DescribePlayerSessions | StartGameSessionPlacement | DescribeGameSessionPlacement | All APIs by task

    Args:
        game_session_id(str): A unique identifier for the game session to add a player to.
        player_id(str): A unique identifier for a player. Player IDs are developer-defined.
        player_data(str, optional): Developer-defined information related to a player. GameLift does not use this data, so it can be formatted as needed for use in the game. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.player_session.create(
                ctx, game_session_id=value, player_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.player_session.create game_session_id=value, player_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="create_player_session",
        op_kwargs={
            "GameSessionId": game_session_id,
            "PlayerId": player_id,
            "PlayerData": player_data,
        },
    )


async def create_multiple(
    hub, ctx, game_session_id: str, player_ids: List, player_data_map: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Reserves open slots in a game session for a group of players. New player sessions can be created in any game session with an open slot that is in ACTIVE status and has a player creation policy of ACCEPT_ALL. To add a single player to a game session, use CreatePlayerSession.  To create player sessions, specify a game session ID and a list of player IDs. Optionally, provide a set of player data for each player ID.  If successful, a slot is reserved in the game session for each player, and new PlayerSession objects are returned with player session IDs. Each player references their player session ID when sending a connection request to the game session, and the game server can use it to validate the player reservation with the GameLift service. Player sessions cannot be updated.  Available in Amazon GameLift Local.   Related actions   CreatePlayerSession | CreatePlayerSessions | DescribePlayerSessions | StartGameSessionPlacement | DescribeGameSessionPlacement | All APIs by task

    Args:
        game_session_id(str): A unique identifier for the game session to add players to.
        player_ids(List): List of unique identifiers for the players to be added.
        player_data_map(Dict, optional): Map of string pairs, each specifying a player ID and a set of developer-defined information related to the player. Amazon GameLift does not use this data, so it can be formatted as needed for use in the game. Any player data strings for player IDs that are not included in the PlayerIds parameter are ignored. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.player_session.create_multiple(
                ctx, game_session_id=value, player_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.player_session.create_multiple game_session_id=value, player_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="create_player_sessions",
        op_kwargs={
            "GameSessionId": game_session_id,
            "PlayerIds": player_ids,
            "PlayerDataMap": player_data_map,
        },
    )


async def describe_all(
    hub,
    ctx,
    game_session_id: str = None,
    player_id: str = None,
    player_session_id: str = None,
    player_session_status_filter: str = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves properties for one or more player sessions.  This action can be used in the following ways:    To retrieve a specific player session, provide the player session ID only.   To retrieve all player sessions in a game session, provide the game session ID only.   To retrieve all player sessions for a specific player, provide a player ID only.   To request player sessions, specify either a player session ID, game session ID, or player ID. You can filter this request by player session status. Use the pagination parameters to retrieve results as a set of sequential pages.  If successful, a PlayerSession object is returned for each session that matches the request.  Available in Amazon GameLift Local.   Related actions   CreatePlayerSession | CreatePlayerSessions | DescribePlayerSessions | StartGameSessionPlacement | DescribeGameSessionPlacement | All APIs by task

    Args:
        game_session_id(str, optional): A unique identifier for the game session to retrieve player sessions for. Defaults to None.
        player_id(str, optional): A unique identifier for a player to retrieve player sessions for. Defaults to None.
        player_session_id(str, optional): A unique identifier for a player session to retrieve. Defaults to None.
        player_session_status_filter(str, optional): Player session status to filter results on. Possible player session statuses include the following:    RESERVED -- The player session request has been received, but the player has not yet connected to the server process and/or been validated.     ACTIVE -- The player has been validated by the server process and is currently connected.    COMPLETED -- The player connection has been dropped.    TIMEDOUT -- A player session request was received, but the player did not connect and/or was not validated within the timeout limit (60 seconds).  . Defaults to None.
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. If a player session ID is specified, this parameter is ignored. Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. If a player session ID is specified, this parameter is ignored. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.player_session.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.player_session.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_player_sessions",
        op_kwargs={
            "GameSessionId": game_session_id,
            "PlayerId": player_id,
            "PlayerSessionId": player_session_id,
            "PlayerSessionStatusFilter": player_session_status_filter,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create_multiple(hub, ctx, fleet_id: str, locations: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds remote locations to a fleet and begins populating the new locations with EC2 instances. The new instances conform to the fleet's instance type, auto-scaling, and other configuration settings.   This operation cannot be used with fleets that don't support remote locations. Fleets can have multiple locations only if they reside in AWS Regions that support this feature (see CreateFleet for the complete list) and were created after the feature was released in March 2021.  To add fleet locations, specify the fleet to be updated and provide a list of one or more locations.  If successful, this operation returns the list of added locations with their status set to NEW. GameLift initiates the process of starting an instance in each added location. You can track the status of each new location by monitoring location creation events using DescribeFleetEvents. Alternatively, you can poll location status by calling DescribeFleetLocationAttributes. After a location status becomes ACTIVE, you can adjust the location's capacity as needed with UpdateFleetCapacity.  Learn more   Setting up fleets   Multi-location fleets   Related actions   CreateFleetLocations | DescribeFleetLocationAttributes | DescribeFleetLocationCapacity | DescribeFleetLocationUtilization | DescribeFleetAttributes | DescribeFleetCapacity | DescribeFleetUtilization | UpdateFleetCapacity | StopFleetActions | DeleteFleetLocations | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet to add locations to. You can use either the fleet ID or ARN value.
        locations(List): A list of locations to deploy additional instances to and manage as part of the fleet. You can add any GameLift-supported AWS Region as a remote location, in the form of an AWS Region code such as us-west-2. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.fleet.location.init.create_multiple(
                ctx, fleet_id=value, locations=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.fleet.location.init.create_multiple fleet_id=value, locations=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="create_fleet_locations",
        op_kwargs={"FleetId": fleet_id, "Locations": locations},
    )


async def delete_multiple(hub, ctx, fleet_id: str, locations: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes locations from a multi-location fleet. When deleting a location, all game server process and all instances that are still active in the location are shut down.  To delete fleet locations, identify the fleet ID and provide a list of the locations to be deleted.  If successful, GameLift sets the location status to DELETING, and begins to shut down existing server processes and terminate instances in each location being deleted. When completed, the location status changes to TERMINATED.  Learn more   Setting up GameLift fleets   Related actions   CreateFleetLocations | DescribeFleetLocationAttributes | DescribeFleetLocationCapacity | DescribeFleetLocationUtilization | DescribeFleetAttributes | DescribeFleetCapacity | DescribeFleetUtilization | UpdateFleetCapacity | StopFleetActions | DeleteFleetLocations | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet to delete locations for. You can use either the fleet ID or ARN value.
        locations(List): The list of fleet locations to delete. Specify locations in the form of an AWS Region code, such as us-west-2.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.fleet.location.init.delete_multiple(
                ctx, fleet_id=value, locations=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.fleet.location.init.delete_multiple fleet_id=value, locations=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="delete_fleet_locations",
        op_kwargs={"FleetId": fleet_id, "Locations": locations},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def put(
    hub,
    ctx,
    action_group: str,
    principals: List,
    profiling_group_name: str,
    revision_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Adds permissions to a profiling group's resource-based policy that are provided using an action group. If a profiling group doesn't have a resource-based policy, one is created for it using the permissions in the action group and the roles and users in the principals parameter.   <p> The one supported action group that can be added is <code>agentPermission</code> which grants <code>ConfigureAgent</code> and <code>PostAgent</code> permissions. For more information, see <a href="https://docs.aws.amazon.com/codeguru/latest/profiler-ug/resource-based-policies.html">Resource-based policies in CodeGuru Profiler</a> in the <i>Amazon CodeGuru Profiler User Guide</i>, <a href="https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_ConfigureAgent.html"> <code>ConfigureAgent</code> </a>, and <a href="https://docs.aws.amazon.com/codeguru/latest/profiler-api/API_PostAgentProfile.html"> <code>PostAgentProfile</code> </a>. </p> <p> The first time you call <code>PutPermission</code> on a profiling group, do not specify a <code>revisionId</code> because it doesn't have a resource-based policy. Subsequent calls must provide a <code>revisionId</code> to specify which revision of the resource-based policy to add the permissions to. </p> <p> The response contains the profiling group's JSON-formatted resource policy. </p>

    Args:
        action_group(str):  Specifies an action group that contains permissions to add to a profiling group resource. One action group is supported, agentPermissions, which grants permission to perform actions required by the profiling agent, ConfigureAgent and PostAgentProfile permissions. .
        principals(List):  A list ARNs for the roles and users you want to grant access to the profiling group. Wildcards are not are supported in the ARNs. .
        profiling_group_name(str): The name of the profiling group to grant access to.
        revision_id(str, optional):  A universally unique identifier (UUID) for the revision of the policy you are adding to the profiling group. Do not specify this when you add permissions to a profiling group for the first time. If a policy already exists on the profiling group, you must specify the revisionId. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguruprofiler.permission.put(
                ctx, action_group=value, principals=value, profiling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguruprofiler.permission.put action_group=value, principals=value, profiling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguruprofiler",
        operation="put_permission",
        op_kwargs={
            "actionGroup": action_group,
            "principals": principals,
            "profilingGroupName": profiling_group_name,
            "revisionId": revision_id,
        },
    )


async def remove(
    hub, ctx, action_group: str, profiling_group_name: str, revision_id: str
) -> Dict:
    r"""
    **Autogenerated function**

     Removes permissions from a profiling group's resource-based policy that are provided using an action group. The one supported action group that can be removed is agentPermission which grants ConfigureAgent and PostAgent permissions. For more information, see Resource-based policies in CodeGuru Profiler in the Amazon CodeGuru Profiler User Guide,  ConfigureAgent , and  PostAgentProfile .

    Args:
        action_group(str):  Specifies an action group that contains the permissions to remove from a profiling group's resource-based policy. One action group is supported, agentPermissions, which grants ConfigureAgent and PostAgentProfile permissions. .
        profiling_group_name(str): The name of the profiling group.
        revision_id(str):  A universally unique identifier (UUID) for the revision of the resource-based policy from which you want to remove permissions. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguruprofiler.permission.remove(
                ctx, action_group=value, profiling_group_name=value, revision_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguruprofiler.permission.remove action_group=value, profiling_group_name=value, revision_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguruprofiler",
        operation="remove_permission",
        op_kwargs={
            "actionGroup": action_group,
            "profilingGroupName": profiling_group_name,
            "revisionId": revision_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub, ctx, fleet_ids: List = None, limit: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the resource capacity settings for one or more fleets. The data returned includes the current fleet capacity (number of EC2 instances), and settings that can control how capacity scaling. For fleets with remote locations, this operation retrieves data for the fleet's home Region only. See DescribeFleetLocationCapacity to get capacity settings for a fleet's remote locations. This operation can be used in the following ways:    To get capacity data for one or more specific fleets, provide a list of fleet IDs or fleet ARNs.    To get capacity data for all fleets, do not provide a fleet identifier.    When requesting multiple fleets, use the pagination parameters to retrieve results as a set of sequential pages.  If successful, a FleetCapacity object is returned for each requested fleet ID. Each FleetCapacity object includes a Location property, which is set to the fleet's home Region. When a list of fleet IDs is provided, attribute objects are returned only for fleets that currently exist.  Some API operations may limit the number of fleet IDs that are allowed in one request. If a request exceeds this limit, the request fails and the error message includes the maximum allowed.   Learn more   Setting up GameLift fleets   GameLift metrics for fleets   Related actions   ListFleets | DescribeEC2InstanceLimits | DescribeFleetAttributes | DescribeFleetCapacity | DescribeFleetEvents | DescribeFleetLocationAttributes | DescribeFleetPortSettings | DescribeFleetUtilization | DescribeRuntimeConfiguration | DescribeScalingPolicies | All APIs by task

    Args:
        fleet_ids(List, optional): A unique identifier for the fleet(s) to retrieve capacity information for. You can use either the fleet ID or ARN value. Leave this parameter empty to retrieve capacity information for all fleets. Defaults to None.
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. This parameter is ignored when the request specifies one or a list of fleet IDs. Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. This parameter is ignored when the request specifies one or a list of fleet IDs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.fleet.capacity.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.fleet.capacity.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_fleet_capacity",
        op_kwargs={"FleetIds": fleet_ids, "Limit": limit, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    fleet_id: str,
    desired_instances: int = None,
    min_size: int = None,
    max_size: int = None,
    location: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates capacity settings for a fleet. For fleets with multiple locations, use this operation to manage capacity settings in each location individually. Fleet capacity determines the number of game sessions and players that can be hosted based on the fleet configuration. Use this operation to set the following fleet capacity properties:    Minimum/maximum size: Set hard limits on fleet capacity. GameLift cannot set the fleet's capacity to a value outside of this range, whether the capacity is changed manually or through automatic scaling.    Desired capacity: Manually set the number of EC2 instances to be maintained in a fleet location. Before changing a fleet's desired capacity, you may want to call DescribeEC2InstanceLimits to get the maximum capacity of the fleet's EC2 instance type. Alternatively, consider using automatic scaling to adjust capacity based on player demand.   This operation can be used in the following ways:    To update capacity for a fleet's home Region, or if the fleet has no remote locations, omit the Location parameter. The fleet must be in ACTIVE status.    To update capacity for a fleet's remote location, include the Location parameter set to the location to be updated. The location must be in ACTIVE status.   If successful, capacity settings are updated immediately. In response a change in desired capacity, GameLift initiates steps to start new instances or terminate existing instances in the requested fleet location. This continues until the location's active instance count matches the new desired instance count. You can track a fleet's current capacity by calling DescribeFleetCapacity or DescribeFleetLocationCapacity. If the requested desired instance count is higher than the instance type's limit, the LimitExceeded exception occurs.  Learn more   Scaling fleet capacity   Related actions   CreateFleetLocations | UpdateFleetAttributes | UpdateFleetCapacity | UpdateFleetPortSettings | UpdateRuntimeConfiguration | StopFleetActions | StartFleetActions | PutScalingPolicy | DeleteFleet | DeleteFleetLocations | DeleteScalingPolicy | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet to update capacity settings for. You can use either the fleet ID or ARN value.
        desired_instances(int, optional): The number of EC2 instances you want to maintain in the specified fleet location. This value must fall between the minimum and maximum size limits. Defaults to None.
        min_size(int, optional): The minimum number of instances that are allowed in the specified fleet location. If this parameter is not set, the default is 0. Defaults to None.
        max_size(int, optional): The maximum number of instances that are allowed in the specified fleet location. If this parameter is not set, the default is 1. Defaults to None.
        location(str, optional): The name of a remote location to update fleet capacity settings for, in the form of an AWS Region code such as us-west-2. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.fleet.capacity.update(ctx, fleet_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.fleet.capacity.update fleet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="update_fleet_capacity",
        op_kwargs={
            "FleetId": fleet_id,
            "DesiredInstances": desired_instances,
            "MinSize": min_size,
            "MaxSize": max_size,
            "Location": location,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put_multiple(
    hub,
    ctx,
    email_identity: str,
    signing_attributes_origin: str,
    signing_attributes: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Used to configure or change the DKIM authentication settings for an email domain identity. You can use this operation to do any of the following:   Update the signing attributes for an identity that uses Bring Your Own DKIM (BYODKIM).   Change from using no DKIM authentication to using Easy DKIM.   Change from using no DKIM authentication to using BYODKIM.   Change from using Easy DKIM to using BYODKIM.   Change from using BYODKIM to using Easy DKIM.

    Args:
        email_identity(str): The email identity that you want to configure DKIM for.
        signing_attributes_origin(str): The method that you want to use to configure DKIM for the identity. There are two possible values:    AWS_SES – Configure DKIM for the identity by using Easy DKIM.    EXTERNAL – Configure DKIM for the identity by using Bring Your Own DKIM (BYODKIM).  .
        signing_attributes(Dict, optional): An object that contains information about the private key and selector that you want to use to configure DKIM for the identity. This object is only required if you want to configure Bring Your Own DKIM (BYODKIM) for the identity. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.email.identity.dkim.signing_attribute.put_multiple(
                ctx, email_identity=value, signing_attributes_origin=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.email.identity.dkim.signing_attribute.put_multiple email_identity=value, signing_attributes_origin=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="put_email_identity_dkim_signing_attributes",
        op_kwargs={
            "EmailIdentity": email_identity,
            "SigningAttributesOrigin": signing_attributes_origin,
            "SigningAttributes": signing_attributes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def generate(
    hub, ctx, entity_path: str, organizations_policy_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Generates a report for service last accessed data for Organizations. You can generate a report for any entities (organization root, organizational unit, or account) or policies in your organization. To call this operation, you must be signed in using your Organizations management account credentials. You can use your long-term IAM user or root user credentials, or temporary credentials from assuming an IAM role. SCPs must be enabled for your organization root. You must have the required IAM and Organizations permissions. For more information, see Refining permissions using service last accessed data in the IAM User Guide. You can generate a service last accessed data report for entities by specifying only the entity's path. This data includes a list of services that are allowed by any service control policies (SCPs) that apply to the entity. You can generate a service last accessed data report for a policy by specifying an entity's path and an optional Organizations policy ID. This data includes a list of services that are allowed by the specified SCP. For each service in both report types, the data includes the most recent account activity that the policy allows to account principals in the entity or the entity's children. For important information about the data, reporting period, permissions required, troubleshooting, and supported Regions see Reducing permissions using service last accessed data in the IAM User Guide.  The data includes all attempts to access Amazon Web Services, not just the successful ones. This includes all attempts that were made using the Management Console, the Amazon Web Services API through any of the SDKs, or any of the command line tools. An unexpected entry in the service last accessed data does not mean that an account has been compromised, because the request might have been denied. Refer to your CloudTrail logs as the authoritative source for information about all API calls and whether they were successful or denied access. For more information, see Logging IAM events with CloudTrail in the IAM User Guide.  This operation returns a JobId. Use this parameter in the  GetOrganizationsAccessReport  operation to check the status of the report generation. To check the status of this request, use the JobId parameter in the  GetOrganizationsAccessReport  operation and test the JobStatus response parameter. When the job is complete, you can retrieve the report. To generate a service last accessed data report for entities, specify an entity path without specifying the optional Organizations policy ID. The type of entity that you specify determines the data returned in the report.    Root – When you specify the organizations root as the entity, the resulting report lists all of the services allowed by SCPs that are attached to your root. For each service, the report includes data for all accounts in your organization except the management account, because the management account is not limited by SCPs.    OU – When you specify an organizational unit (OU) as the entity, the resulting report lists all of the services allowed by SCPs that are attached to the OU and its parents. For each service, the report includes data for all accounts in the OU or its children. This data excludes the management account, because the management account is not limited by SCPs.    management account – When you specify the management account, the resulting report lists all Amazon Web Services services, because the management account is not limited by SCPs. For each service, the report includes data for only the management account.    Account – When you specify another account as the entity, the resulting report lists all of the services allowed by SCPs that are attached to the account and its parents. For each service, the report includes data for only the specified account.   To generate a service last accessed data report for policies, specify an entity path and the optional Organizations policy ID. The type of entity that you specify determines the data returned for each service.    Root – When you specify the root entity and a policy ID, the resulting report lists all of the services that are allowed by the specified SCP. For each service, the report includes data for all accounts in your organization to which the SCP applies. This data excludes the management account, because the management account is not limited by SCPs. If the SCP is not attached to any entities in the organization, then the report will return a list of services with no data.    OU – When you specify an OU entity and a policy ID, the resulting report lists all of the services that are allowed by the specified SCP. For each service, the report includes data for all accounts in the OU or its children to which the SCP applies. This means that other accounts outside the OU that are affected by the SCP might not be included in the data. This data excludes the management account, because the management account is not limited by SCPs. If the SCP is not attached to the OU or one of its children, the report will return a list of services with no data.    management account – When you specify the management account, the resulting report lists all Amazon Web Services services, because the management account is not limited by SCPs. If you specify a policy ID in the CLI or API, the policy is ignored. For each service, the report includes data for only the management account.    Account – When you specify another account entity and a policy ID, the resulting report lists all of the services that are allowed by the specified SCP. For each service, the report includes data for only the specified account. This means that other accounts in the organization that are affected by the SCP might not be included in the data. If the SCP is not attached to the account, the report will return a list of services with no data.    Service last accessed data does not use other policy types when determining whether a principal could access a service. These other policy types include identity-based policies, resource-based policies, access control lists, IAM permissions boundaries, and STS assume role policies. It only applies SCP logic. For more about the evaluation of policy types, see Evaluating policies in the IAM User Guide.  For more information about service last accessed data, see Reducing policy scope by viewing user activity in the IAM User Guide.

    Args:
        entity_path(str): The path of the Organizations entity (root, OU, or account). You can build an entity path using the known structure of your organization. For example, assume that your account ID is 123456789012 and its parent OU ID is ou-rge0-awsabcde. The organization root ID is r-f6g7h8i9j0example and your organization ID is o-a1b2c3d4e5. Your entity path is o-a1b2c3d4e5/r-f6g7h8i9j0example/ou-rge0-awsabcde/123456789012.
        organizations_policy_id(str, optional): The identifier of the Organizations service control policy (SCP). This parameter is optional. This ID is used to generate information about when an account principal that is limited by the SCP attempted to access an Amazon Web Services service. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.organization_access_report.generate(ctx, entity_path=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.organization_access_report.generate entity_path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="generate_organizations_access_report",
        op_kwargs={
            "EntityPath": entity_path,
            "OrganizationsPolicyId": organizations_policy_id,
        },
    )


async def get(
    hub,
    ctx,
    job_id: str,
    max_items: int = None,
    marker: str = None,
    sort_key: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the service last accessed data report for Organizations that was previously generated using the  GenerateOrganizationsAccessReport  operation. This operation retrieves the status of your report job and the report contents. Depending on the parameters that you passed when you generated the report, the data returned could include different information. For details, see GenerateOrganizationsAccessReport. To call this operation, you must be signed in to the management account in your organization. SCPs must be enabled for your organization root. You must have permissions to perform this operation. For more information, see Refining permissions using service last accessed data in the IAM User Guide. For each service that principals in an account (root users, IAM users, or IAM roles) could access using SCPs, the operation returns details about the most recent access attempt. If there was no attempt, the service is listed without details about the most recent attempt to access the service. If the operation fails, it returns the reason that it failed. By default, the list is sorted by service namespace.

    Args:
        job_id(str): The identifier of the request generated by the GenerateOrganizationsAccessReport operation.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.
        sort_key(str, optional): The key that is used to sort the results. If you choose the namespace key, the results are returned in alphabetical order. If you choose the time key, the results are sorted numerically by the date and time. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.organization_access_report.get(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.organization_access_report.get job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="get_organizations_access_report",
        op_kwargs={
            "JobId": job_id,
            "MaxItems": max_items,
            "Marker": marker,
            "SortKey": sort_key,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    password_length: int = None,
    exclude_characters: str = None,
    exclude_numbers: bool = None,
    exclude_punctuation: bool = None,
    exclude_uppercase: bool = None,
    exclude_lowercase: bool = None,
    include_space: bool = None,
    require_each_included_type: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Generates a random password of the specified complexity. This operation is intended for use in the Lambda rotation function. Per best practice, we recommend that you specify the maximum length and include every character type that the system you are generating a password for can support.  Minimum permissions  To run this command, you must have the following permissions:   secretsmanager:GetRandomPassword

    Args:
        password_length(int, optional): The desired length of the generated password. The default value if you do not include this parameter is 32 characters. Defaults to None.
        exclude_characters(str, optional): A string that includes characters that should not be included in the generated password. The default is that all characters from the included sets can be used. Defaults to None.
        exclude_numbers(bool, optional): Specifies that the generated password should not include digits. The default if you do not include this switch parameter is that digits can be included. Defaults to None.
        exclude_punctuation(bool, optional): Specifies that the generated password should not include punctuation characters. The default if you do not include this switch parameter is that punctuation characters can be included. The following are the punctuation characters that can be included in the generated password if you don't explicitly exclude them with ExcludeCharacters or ExcludePunctuation:  ! " # $ % & ' ( ) * + , - . / : ; < = > ? @ [ \ ] ^ _ ` { | } ~ . Defaults to None.
        exclude_uppercase(bool, optional): Specifies that the generated password should not include uppercase letters. The default if you do not include this switch parameter is that uppercase letters can be included. Defaults to None.
        exclude_lowercase(bool, optional): Specifies that the generated password should not include lowercase letters. The default if you do not include this switch parameter is that lowercase letters can be included. Defaults to None.
        include_space(bool, optional): Specifies that the generated password can include the space character. The default if you do not include this switch parameter is that the space character is not included. Defaults to None.
        require_each_included_type(bool, optional): A boolean value that specifies whether the generated password must include at least one of every allowed character type. The default value is True and the operation requires at least one of every character type. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.secretsmanager.random_password.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.secretsmanager.random_password.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="secretsmanager",
        operation="get_random_password",
        op_kwargs={
            "PasswordLength": password_length,
            "ExcludeCharacters": exclude_characters,
            "ExcludeNumbers": exclude_numbers,
            "ExcludePunctuation": exclude_punctuation,
            "ExcludeUppercase": exclude_uppercase,
            "ExcludeLowercase": exclude_lowercase,
            "IncludeSpace": include_space,
            "RequireEachIncludedType": require_each_included_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def promote(hub, ctx, resource_share_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Resource shares that were created by attaching a policy to a resource are visible only to the resource share owner, and the resource share cannot be modified in AWS RAM. Use this API action to promote the resource share. When you promote the resource share, it becomes:   Visible to all principals that it is shared with.   Modifiable in AWS RAM.

    Args:
        resource_share_arn(str): The ARN of the resource share to promote.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.share.created_from_policy.promote(
                ctx, resource_share_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.share.created_from_policy.promote resource_share_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="promote_resource_share_created_from_policy",
        op_kwargs={"resourceShareArn": resource_share_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def deregister(hub, ctx, instance_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes the server or virtual machine from the list of registered servers. You can reregister the instance again at any time. If you don't plan to use Run Command on the server, we suggest uninstalling SSM Agent first.

    Args:
        instance_id(str): The ID assigned to the managed instance when you registered it using the activation process. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.managed_instance.init.deregister(ctx, instance_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.managed_instance.init.deregister instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="deregister_managed_instance",
        op_kwargs={"InstanceId": instance_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    security_profile_name: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the targets (thing groups) associated with a given Device Defender security profile.

    Args:
        security_profile_name(str): The security profile.
        next_token(str, optional): The token for the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return at one time. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.target.for_.security_profile.list(
                ctx, security_profile_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.target.for_.security_profile.list security_profile_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_targets_for_security_profile",
        op_kwargs={
            "securityProfileName": security_profile_name,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )
